#include "em_device.h"
#include "em_cryotimer.h"
#include "em_cmu.h"
#include "em_emu.h"
#include "em_gpio.h"

void EMU_setup(void)
{
	EMU_DCDCInit_TypeDef dcdcInit = EMU_DCDCINIT_DEFAULT;
	EMU_DCDCInit(&dcdcInit);							// init DC/DC converter
}

void CMU_setup(void)
{
	CMU_LFXOInit_TypeDef lfxoInit = CMU_LFXOINIT_DEFAULT;
	CMU_LFXOInit(&lfxoInit);
	SystemLFXOClockSet(32768);
	CMU_ClockSelectSet(cmuClock_HF, cmuSelect_HFRCO);	// select 19 MHz HFRCO as clock source
	CMU_ClockEnable(cmuClock_HFLE, true);				// enable LE clock access
	CMU_ClockSelectSet(cmuClock_LFA, cmuSelect_LFXO);
	CMU_ClockSelectSet(cmuClock_LFE, cmuSelect_LFXO);
}

void GPIO_setup(void)									// configure GPIO ports
{
	CMU_ClockEnable(cmuClock_GPIO, true);
	GPIO_PinModeSet(gpioPortD, 9, gpioModePushPull, 0);	// red LED control
}

void CRYOTIMER_setup(void)
{
	CMU_ClockEnable(cmuClock_CRYOTIMER, true);
	CRYOTIMER_Init_TypeDef init = CRYOTIMER_INIT_DEFAULT;
	init.osc = cryotimerOscLFXO;   					// Use the ULFRCO
	init.presc = cryotimerPresc_1; 						// Set the prescaler
	init.period = cryotimerPeriod_32k;  				// Set when wakeup events occur
	init.enable = true;              					// Start the cryotimer after initialization is done
	CRYOTIMER_Init(&init);
	CRYOTIMER_IntEnable(CRYOTIMER_IEN_PERIOD);
	NVIC_EnableIRQ(CRYOTIMER_IRQn);
}
